@@ -5,9 +5,12 @@
 */
 
 #include "nettesthelper.h"
-#include <QProcess>
 #include <netwm.h>
+
+#include <QProcess>
+#include <QStandardPaths>
 #include <qtest_widgets.h>
+
 // system
 #include <unistd.h>
 
@@ -15,14 +18,7 @@ Q_DECLARE_METATYPE(NET::State)
 Q_DECLARE_METATYPE(NET::States)
 Q_DECLARE_METATYPE(NET::Actions)
 
-class Property : public QScopedPointer<xcb_get_property_reply_t, QScopedPointerPodDeleter>
-{
-public:
-    Property(xcb_get_property_reply_t *p = nullptr)
-        : QScopedPointer<xcb_get_property_reply_t, QScopedPointerPodDeleter>(p)
-    {
-    }
-};
+using Property = UniqueCPointer<xcb_get_property_reply_t>;
 
 // clang-format off
 #define INFO NETWinInfo info(m_connection, m_testWindow, m_rootWindow, NET::WMAllProperties, NET::WM2AllProperties, NET::WindowManager);
@@ -36,7 +32,7 @@ public:
     xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, m_testWindow, \
                                        atom, type, 0, length); \
     Property reply(xcb_get_property_reply(connection(), cookie, nullptr)); \
-    QVERIFY(!reply.isNull()); \
+    QVERIFY(reply); \
     QCOMPARE(reply->format, uint8_t(formatSize)); \
     QCOMPARE(reply->value_len, uint32_t(length));
 
@@ -44,7 +40,7 @@ public:
     xcb_get_property_cookie_t cookieDeleted = xcb_get_property_unchecked(connection(), false, m_testWindow, \
             atom, t, 0, 1); \
     Property replyDeleted(xcb_get_property_reply(connection(), cookieDeleted, nullptr)); \
-    QVERIFY(!replyDeleted.isNull()); \
+    QVERIFY(replyDeleted); \
     QVERIFY(replyDeleted->type == XCB_ATOM_NONE);
 
 class NetWinInfoTestWM : public QObject
@@ -80,8 +76,8 @@ private:
         return m_connection;
     }
     xcb_connection_t *m_connection;
-    QVector<xcb_connection_t*> m_connections;
-    QScopedPointer<QProcess> m_xvfb;
+    QList<xcb_connection_t*> m_connections;
+    std::unique_ptr<QProcess> m_xvfb;
     xcb_window_t m_rootWindow;
     xcb_window_t m_testWindow;
     QByteArray m_displayNumber;
@@ -105,6 +101,10 @@ void NetWinInfoTestWM::init()
     m_connection = nullptr;
     m_rootWindow = XCB_WINDOW_NONE;
     m_testWindow = XCB_WINDOW_NONE;
+
+    const QString xfvbExec = QStandardPaths::findExecutable(QStringLiteral("Xvfb"));
+    QVERIFY(!xfvbExec.isEmpty());
+
     // start Xvfb
     m_xvfb.reset(new QProcess);
 
@@ -162,14 +162,14 @@ void NetWinInfoTestWM::cleanup()
 void NetWinInfoTestWM::waitForPropertyChange(NETWinInfo *info, xcb_atom_t atom, NET::Property prop, NET::Property2 prop2)
 {
     while (true) {
-        KXUtils::ScopedCPointer<xcb_generic_event_t> event(xcb_wait_for_event(connection()));
-        if (event.isNull()) {
+        UniqueCPointer<xcb_generic_event_t> event(xcb_wait_for_event(connection()));
+        if (!event) {
             break;
         }
         if ((event->response_type & ~0x80) != XCB_PROPERTY_NOTIFY) {
             continue;
         }
-        xcb_property_notify_event_t *pe = reinterpret_cast<xcb_property_notify_event_t *>(event.data());
+        xcb_property_notify_event_t *pe = reinterpret_cast<xcb_property_notify_event_t *>(event.get());
         if (pe->window != m_testWindow) {
             continue;
         }
@@ -178,7 +178,7 @@ void NetWinInfoTestWM::waitForPropertyChange(NETWinInfo *info, xcb_atom_t atom,
         }
         NET::Properties dirty;
         NET::Properties2 dirty2;
-        info->event(event.data(), &dirty, &dirty2);
+        info->event(event.get(), &dirty, &dirty2);
         if (prop != 0) {
             QVERIFY(dirty & prop);
         }
@@ -213,7 +213,7 @@ bool NetWinInfoTestWM::hasAtomFlag(const xcb_atom_t *atoms, int atomsLength, con
 void NetWinInfoTestWM::testAllowedActions_data()
 {
     QTest::addColumn<NET::Actions>("actions");
-    QTest::addColumn<QVector<QByteArray> >("names");
+    QTest::addColumn<QList<QByteArray> >("names");
 
     const QByteArray move       = QByteArrayLiteral("_NET_WM_ACTION_MOVE");
     const QByteArray resize     = QByteArrayLiteral("_NET_WM_ACTION_RESIZE");
@@ -226,18 +226,18 @@ void NetWinInfoTestWM::testAllowedActions_data()
     const QByteArray desktop    = QByteArrayLiteral("_NET_WM_ACTION_CHANGE_DESKTOP");
     const QByteArray close      = QByteArrayLiteral("_NET_WM_ACTION_CLOSE");
 
-    QTest::newRow("move")       << NET::Actions(NET::ActionMove)          << (QVector<QByteArray>() << move);
-    QTest::newRow("resize")     << NET::Actions(NET::ActionResize)        << (QVector<QByteArray>() << resize);
-    QTest::newRow("minimize")   << NET::Actions(NET::ActionMinimize)      << (QVector<QByteArray>() << minimize);
-    QTest::newRow("shade")      << NET::Actions(NET::ActionShade)         << (QVector<QByteArray>() << shade);
-    QTest::newRow("stick")      << NET::Actions(NET::ActionStick)         << (QVector<QByteArray>() << stick);
-    QTest::newRow("maxVert")    << NET::Actions(NET::ActionMaxVert)       << (QVector<QByteArray>() << maxVert);
-    QTest::newRow("maxHoriz")   << NET::Actions(NET::ActionMaxHoriz)      << (QVector<QByteArray>() << maxHoriz);
-    QTest::newRow("fullscreen") << NET::Actions(NET::ActionFullScreen)    << (QVector<QByteArray>() << fullscreen);
-    QTest::newRow("desktop")    << NET::Actions(NET::ActionChangeDesktop) << (QVector<QByteArray>() << desktop);
-    QTest::newRow("close")      << NET::Actions(NET::ActionClose)         << (QVector<QByteArray>() << close);
+    QTest::newRow("move")       << NET::Actions(NET::ActionMove)          << (QList<QByteArray>() << move);
+    QTest::newRow("resize")     << NET::Actions(NET::ActionResize)        << (QList<QByteArray>() << resize);
+    QTest::newRow("minimize")   << NET::Actions(NET::ActionMinimize)      << (QList<QByteArray>() << minimize);
+    QTest::newRow("shade")      << NET::Actions(NET::ActionShade)         << (QList<QByteArray>() << shade);
+    QTest::newRow("stick")      << NET::Actions(NET::ActionStick)         << (QList<QByteArray>() << stick);
+    QTest::newRow("maxVert")    << NET::Actions(NET::ActionMaxVert)       << (QList<QByteArray>() << maxVert);
+    QTest::newRow("maxHoriz")   << NET::Actions(NET::ActionMaxHoriz)      << (QList<QByteArray>() << maxHoriz);
+    QTest::newRow("fullscreen") << NET::Actions(NET::ActionFullScreen)    << (QList<QByteArray>() << fullscreen);
+    QTest::newRow("desktop")    << NET::Actions(NET::ActionChangeDesktop) << (QList<QByteArray>() << desktop);
+    QTest::newRow("close")      << NET::Actions(NET::ActionClose)         << (QList<QByteArray>() << close);
 
-    QTest::newRow("none") << NET::Actions() << QVector<QByteArray>();
+    QTest::newRow("none") << NET::Actions() << QList<QByteArray>();
 
     QTest::newRow("all") << NET::Actions(NET::ActionMove |
                                     NET::ActionResize |
@@ -249,7 +249,7 @@ void NetWinInfoTestWM::testAllowedActions_data()
                                     NET::ActionFullScreen |
                                     NET::ActionChangeDesktop |
                                     NET::ActionClose)
-                         << (QVector<QByteArray>() << move << resize << minimize << shade <<
+                         << (QList<QByteArray>() << move << resize << minimize << shade <<
                              stick << maxVert << maxHoriz <<
                              fullscreen << desktop << close);
 }
@@ -266,10 +266,10 @@ void NetWinInfoTestWM::testAllowedActions()
     QCOMPARE(info.allowedActions(), actions);
 
     // compare with the X property
-    QFETCH(QVector<QByteArray>, names);
+    QFETCH(QList<QByteArray>, names);
     QVERIFY(atom != XCB_ATOM_NONE);
     GETPROP(XCB_ATOM_ATOM, names.size(), 32)
-    xcb_atom_t *atoms = reinterpret_cast<xcb_atom_t *>(xcb_get_property_value(reply.data()));
+    xcb_atom_t *atoms = reinterpret_cast<xcb_atom_t *>(xcb_get_property_value(reply.get()));
     for (int i = 0; i < names.size(); ++i) {
         QVERIFY(hasAtomFlag(atoms, names.size(), names.at(i)));
     }
@@ -303,7 +303,7 @@ void NetWinInfoTestWM::testDesktop()
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
     GETPROP(XCB_ATOM_CARDINAL, 1, 32)
-    QTEST(reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.data()))[0], "propertyDesktop");
+    QTEST(reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.get()))[0], "propertyDesktop");
 
     // and wait for our event
     waitForPropertyChange(&info, atom, NET::WMDesktop);
@@ -344,7 +344,7 @@ void NetWinInfoTestWM::testStrut(xcb_atom_t atom, NETStrut(NETWinInfo:: *getter)
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
     GETPROP(XCB_ATOM_CARDINAL, 4, 32)
-    uint32_t *data = reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.data()));
+    uint32_t *data = reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.get()));
     QCOMPARE(data[0], uint32_t(newExtents.left));
     QCOMPARE(data[1], uint32_t(newExtents.right));
     QCOMPARE(data[2], uint32_t(newExtents.top));
@@ -404,7 +404,7 @@ void NetWinInfoTestWM::testOpacity()
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
     GETPROP(XCB_ATOM_CARDINAL, 1, 32)
-    QCOMPARE(reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.data()))[0], opacity);
+    QCOMPARE(reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.get()))[0], opacity);
 
     // and wait for our event
     waitForPropertyChange(&info, atom, NET::Property(0), NET::WM2Opacity);
@@ -414,7 +414,7 @@ void NetWinInfoTestWM::testOpacity()
 void NetWinInfoTestWM::testState_data()
 {
     QTest::addColumn<NET::States>("states");
-    QTest::addColumn<QVector<QByteArray> >("names");
+    QTest::addColumn<QList<QByteArray> >("names");
 
     const QByteArray modal            = QByteArrayLiteral("_NET_WM_STATE_MODAL");
     const QByteArray sticky           = QByteArrayLiteral("_NET_WM_STATE_STICKY");
@@ -432,20 +432,20 @@ void NetWinInfoTestWM::testState_data()
     const QByteArray demandsAttention = QByteArrayLiteral("_NET_WM_STATE_DEMANDS_ATTENTION");
     const QByteArray focused          = QByteArrayLiteral("_NET_WM_STATE_FOCUSED");
 
-    QTest::newRow("modal")            << NET::States(NET::Modal)            << (QVector<QByteArray>() << modal);
-    QTest::newRow("sticky")           << NET::States(NET::Sticky)           << (QVector<QByteArray>() << sticky);
-    QTest::newRow("maxVert")          << NET::States(NET::MaxVert)          << (QVector<QByteArray>() << maxVert);
-    QTest::newRow("maxHoriz")         << NET::States(NET::MaxHoriz)         << (QVector<QByteArray>() << maxHoriz);
-    QTest::newRow("shaded")           << NET::States(NET::Shaded)           << (QVector<QByteArray>() << shaded);
-    QTest::newRow("skipTaskbar")      << NET::States(NET::SkipTaskbar)      << (QVector<QByteArray>() << skipTaskbar);
-    QTest::newRow("keepAbove")        << NET::States(NET::KeepAbove)        << (QVector<QByteArray>() << keepAbove << staysOnTop);
-    QTest::newRow("skipPager")        << NET::States(NET::SkipPager)        << (QVector<QByteArray>() << skipPager);
-    QTest::newRow("hidden")           << NET::States(NET::Hidden)           << (QVector<QByteArray>() << hidden);
-    QTest::newRow("fullScreen")       << NET::States(NET::FullScreen)       << (QVector<QByteArray>() << fullScreen);
-    QTest::newRow("keepBelow")        << NET::States(NET::KeepBelow)        << (QVector<QByteArray>() << keepBelow);
-    QTest::newRow("demandsAttention") << NET::States(NET::DemandsAttention) << (QVector<QByteArray>() << demandsAttention);
-    QTest::newRow("skipSwitcher")     << NET::States(NET::SkipSwitcher)     << (QVector<QByteArray>() << skipSwitcher);
-    QTest::newRow("focused")          << NET::States(NET::Focused)          << (QVector<QByteArray>() << focused);
+    QTest::newRow("modal")            << NET::States(NET::Modal)            << (QList<QByteArray>() << modal);
+    QTest::newRow("sticky")           << NET::States(NET::Sticky)           << (QList<QByteArray>() << sticky);
+    QTest::newRow("maxVert")          << NET::States(NET::MaxVert)          << (QList<QByteArray>() << maxVert);
+    QTest::newRow("maxHoriz")         << NET::States(NET::MaxHoriz)         << (QList<QByteArray>() << maxHoriz);
+    QTest::newRow("shaded")           << NET::States(NET::Shaded)           << (QList<QByteArray>() << shaded);
+    QTest::newRow("skipTaskbar")      << NET::States(NET::SkipTaskbar)      << (QList<QByteArray>() << skipTaskbar);
+    QTest::newRow("keepAbove")        << NET::States(NET::KeepAbove)        << (QList<QByteArray>() << keepAbove << staysOnTop);
+    QTest::newRow("skipPager")        << NET::States(NET::SkipPager)        << (QList<QByteArray>() << skipPager);
+    QTest::newRow("hidden")           << NET::States(NET::Hidden)           << (QList<QByteArray>() << hidden);
+    QTest::newRow("fullScreen")       << NET::States(NET::FullScreen)       << (QList<QByteArray>() << fullScreen);
+    QTest::newRow("keepBelow")        << NET::States(NET::KeepBelow)        << (QList<QByteArray>() << keepBelow);
+    QTest::newRow("demandsAttention") << NET::States(NET::DemandsAttention) << (QList<QByteArray>() << demandsAttention);
+    QTest::newRow("skipSwitcher")     << NET::States(NET::SkipSwitcher)     << (QList<QByteArray>() << skipSwitcher);
+    QTest::newRow("focused")          << NET::States(NET::Focused)          << (QList<QByteArray>() << focused);
 
     // TODO: it's possible to be keep above and below at the same time?!?
     QTest::newRow("all") << NET::States(NET::Modal |
@@ -461,7 +461,7 @@ void NetWinInfoTestWM::testState_data()
                                    NET::DemandsAttention |
                                    NET::SkipSwitcher  |
                                    NET::Focused)
-                         << (QVector<QByteArray>() << modal << sticky << maxVert << maxHoriz
+                         << (QList<QByteArray>() << modal << sticky << maxVert << maxHoriz
                              << shaded << skipTaskbar << keepAbove
                              << skipPager << hidden << fullScreen
                              << keepBelow << demandsAttention << staysOnTop << skipSwitcher << focused);
@@ -479,10 +479,10 @@ void NetWinInfoTestWM::testState()
     QCOMPARE(info.state(), states);
 
     // compare with the X property
-    QFETCH(QVector<QByteArray>, names);
+    QFETCH(QList<QByteArray>, names);
     QVERIFY(atom != XCB_ATOM_NONE);
     GETPROP(XCB_ATOM_ATOM, names.size(), 32)
-    xcb_atom_t *atoms = reinterpret_cast<xcb_atom_t *>(xcb_get_property_value(reply.data()));
+    xcb_atom_t *atoms = reinterpret_cast<xcb_atom_t *>(xcb_get_property_value(reply.get()));
     for (int i = 0; i < names.size(); ++i) {
         QVERIFY(hasAtomFlag(atoms, names.size(), names.at(i)));
     }
@@ -507,7 +507,7 @@ void NetWinInfoTestWM::testVisibleIconName()
     QVERIFY(atom != XCB_ATOM_NONE);
     QVERIFY(utf8String != XCB_ATOM_NONE);
     GETPROP(utf8String, 3, 8)
-    QCOMPARE(reinterpret_cast<const char *>(xcb_get_property_value(reply.data())), "foo");
+    QCOMPARE(reinterpret_cast<const char *>(xcb_get_property_value(reply.get())), "foo");
 
     // and wait for our event
     waitForPropertyChange(&info, atom, NET::WMVisibleIconName);
@@ -543,7 +543,7 @@ void NetWinInfoTestWM::testVisibleName()
     QVERIFY(atom != XCB_ATOM_NONE);
     QVERIFY(utf8String != XCB_ATOM_NONE);
     GETPROP(utf8String, 3, 8)
-    QCOMPARE(reinterpret_cast<const char *>(xcb_get_property_value(reply.data())), "foo");
+    QCOMPARE(reinterpret_cast<const char *>(xcb_get_property_value(reply.get())), "foo");
 
     // and wait for our event
     waitForPropertyChange(&info, atom, NET::WMVisibleName);
@@ -594,12 +594,9 @@ void NetWinInfoTestWM::testFullscreenMonitors()
                      XCB_EVENT_MASK_FOCUS_CHANGE | // For NotifyDetailNone
                      XCB_EVENT_MASK_EXPOSURE
     };
-    QScopedPointer<xcb_generic_error_t, QScopedPointerPodDeleter> redirectCheck(xcb_request_check(connection(),
-                                                                        xcb_change_window_attributes_checked(connection(),
-                                                                                                                m_rootWindow,
-                                                                                                                XCB_CW_EVENT_MASK,
-                                                                                                                maskValues)));
-    QVERIFY(redirectCheck.isNull());
+    UniqueCPointer<xcb_generic_error_t> redirectCheck(xcb_request_check(connection(), xcb_change_window_attributes_checked(connection(),
+                                                      m_rootWindow, XCB_CW_EVENT_MASK, maskValues)));
+    QVERIFY(!redirectCheck);
 
     KXUtils::Atom atom(connection(), QByteArrayLiteral("_NET_WM_FULLSCREEN_MONITORS"));
 
@@ -620,8 +617,8 @@ void NetWinInfoTestWM::testFullscreenMonitors()
     MockWinInfo info(connection(), m_testWindow, m_rootWindow);
 
     while (true) {
-        KXUtils::ScopedCPointer<xcb_generic_event_t> event(xcb_wait_for_event(connection()));
-        if (event.isNull()) {
+        UniqueCPointer<xcb_generic_event_t> event(xcb_wait_for_event(connection()));
+        if (!event) {
             break;
         }
         if ((event->response_type & ~0x80) != XCB_CLIENT_MESSAGE) {
@@ -631,7 +628,7 @@ void NetWinInfoTestWM::testFullscreenMonitors()
         NET::Properties dirtyProtocols;
         NET::Properties2 dirtyProtocols2;
         QCOMPARE(info.fullscreenMonitors().isSet(), false);
-        info.event(event.data(), &dirtyProtocols, &dirtyProtocols2);
+        info.event(event.get(), &dirtyProtocols, &dirtyProtocols2);
         QCOMPARE(info.fullscreenMonitors().isSet(), true);
         break;
     }
