@@ -283,6 +283,12 @@ bool isShiftAsModifierAllowed(int keyQt)
     case Qt::Key_LaunchD:
     case Qt::Key_LaunchE:
     case Qt::Key_LaunchF:
+    case Qt::Key_Shift:
+    case Qt::Key_Control:
+    case Qt::Key_Meta:
+    case Qt::Key_Alt:
+    case Qt::Key_Super_L:
+    case Qt::Key_Super_R:
         return true;
 
     default:
@@ -360,10 +366,15 @@ static const TransKey g_rgQtToSymX[] = {
     { Qt::Key_Down,       XK_Down },
     { Qt::Key_PageUp,      XK_Prior },
     { Qt::Key_PageDown,       XK_Next },
-    //{ Qt::Key_Shift,      0 },
-    //{ Qt::Key_Control,    0 },
-    //{ Qt::Key_Meta,       0 },
-    //{ Qt::Key_Alt,        0 },
+    { Qt::Key_Shift,      XK_Shift_L },
+    { Qt::Key_Shift,      XK_Shift_R },
+    { Qt::Key_Shift,      XK_Shift_Lock },
+    { Qt::Key_Control,    XK_Control_L },
+    { Qt::Key_Control,    XK_Control_R },
+    { Qt::Key_Meta,       XK_Meta_L },
+    { Qt::Key_Meta,       XK_Meta_R },
+    { Qt::Key_Alt,        XK_Alt_L },
+    { Qt::Key_Alt,        XK_Alt_R },
     { Qt::Key_CapsLock,   XK_Caps_Lock },
     { Qt::Key_NumLock,    XK_Num_Lock },
     { Qt::Key_ScrollLock, XK_Scroll_Lock },
